==> estateplat-common-1.2.4-20201118.081108-520-sources.jar: cn/gtmap/estateplat/model/exchange/unidofrmity/HeadModel.java <==
package cn.gtmap.estateplat.model.exchange.unidofrmity;

import cn.gtmap.estateplat.utils.JaxbDateAdapter;
import cn.gtmap.estateplat.utils.JaxbStringNoNullAdapter;

import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;
import java.util.Date;

@XmlRootElement(
        name = "Head"
)
public class HeadModel {
    private String bizMsgID;
    private String ASID;
    private String areaCode;
    private String recType;
    private String rightType;
    private String regType;
    private Date createDate;
    private String recFlowID;
    private String regOrgID;
    private String parcelID;
    private String estateNum;
    private String digitalSign;
    private String preEstateNum;
    private String certCount;
    private String proofCount;
    private String preCertID;
    private String exchangeMode;
    private String logoutBusinessNum;
    public HeadModel() {
    }

    @XmlElement(
            name = "BizMsgID"
    )
    public String getBizMsgID() {
        return this.bizMsgID;
    }

    public void setBizMsgID(String bizMsgID) {
        this.bizMsgID = bizMsgID;
    }

    @XmlElement(
            name = "ASID"
    )
    public String getASID() {
        return this.ASID;
    }

    public void setASID(String ASID) {
        this.ASID = ASID;
    }

    @XmlElement(
            name = "AreaCode"
    )
    public String getAreaCode() {
        return this.areaCode;
    }

    public void setAreaCode(String areaCode) {
        this.areaCode = areaCode;
    }

    @XmlElement(
            name = "RecType"
    )
    public String getRecType() {
        return this.recType;
    }

    public void setRecType(String recType) {
        this.recType = recType;
    }

    @XmlElement(
            name = "RightType"
    )
    public String getRightType() {
        return this.rightType;
    }

    public void setRightType(String rightType) {
        this.rightType = rightType;
    }

    @XmlElement(
            name = "RegType"
    )
    public String getRegType() {
        return this.regType;
    }

    public void setRegType(String regType) {
        this.regType = regType;
    }

    @XmlElement(
            name = "CreateDate"
    )
    @XmlJavaTypeAdapter(JaxbDateAdapter.class)
    public Date getCreateDate() {
        return this.createDate;
    }

    public void setCreateDate(Date createDate) {
        this.createDate = createDate;
    }

    @XmlElement(
            name = "RecFlowID"
    )
    public String getRecFlowID() {
        return this.recFlowID;
    }

    public void setRecFlowID(String recFlowID) {
        this.recFlowID = recFlowID;
    }

    @XmlElement(
            name = "RegOrgID"
    )
    public String getRegOrgID() {
        return this.regOrgID;
    }

    public void setRegOrgID(String regOrgID) {
        this.regOrgID = regOrgID;
    }

    @XmlElement(
            name = "ParcelID"
    )
    public String getParcelID() {
        return this.parcelID;
    }

    public void setParcelID(String parcelID) {
        this.parcelID = parcelID;
    }

    @XmlElement(
            name = "EstateNum"
    )
    public String getEstateNum() {
        return this.estateNum;
    }

    public void setEstateNum(String estateNum) {
        this.estateNum = estateNum;
    }

    @XmlElement(
            name = "DigitalSign"
    )
    public String getDigitalSign() {
        return this.digitalSign;
    }

    public void setDigitalSign(String digitalSign) {
        this.digitalSign = digitalSign;
    }

    @XmlElement(
            name = "PreEstateNum"
    )
    public String getPreEstateNum() {
        return this.preEstateNum;
    }

    public void setPreEstateNum(String preEstateNum) {
        this.preEstateNum = preEstateNum;
    }

    @XmlElement(
            name = "CertCount"
    )
    public String getCertCount() {
        return this.certCount;
    }

    public void setCertCount(String certCount) {
        this.certCount = certCount;
    }

    @XmlElement(
            name = "ProofCount"
    )
    public String getProofCount() {
        return this.proofCount;
    }

    public void setProofCount(String proofCount) {
        this.proofCount = proofCount;
    }

    @XmlElement(
            name = "PreCertID"
    )
    public String getPreCertID() {
        return this.preCertID;
    }

    public void setPreCertID(String preCertID) {
        this.preCertID = preCertID;
    }

    @XmlElement(
            name = "ExchangeMode"
    )
    @XmlJavaTypeAdapter(JaxbStringNoNullAdapter.class)
    public String getExchangeMode() {
        return exchangeMode;
    }

    public void setExchangeMode(String exchangeMode) {
        this.exchangeMode = exchangeMode;
    }
    @XmlElement(
            name = "LogoutBusinessNum"
    )
    @XmlJavaTypeAdapter(JaxbStringNoNullAdapter.class)
    public String getLogoutBusinessNum() {
        return logoutBusinessNum;
    }

    public void setLogoutBusinessNum(String logoutBusinessNum) {
        this.logoutBusinessNum = logoutBusinessNum;
    }
}

==> estateplat-common-1.2.4-20210826.032016-854-sources.jar: cn/gtmap/estateplat/model/exchange/unidofrmity/HeadModel.java <==
package cn.gtmap.estateplat.model.exchange.unidofrmity;

import cn.gtmap.estateplat.utils.JaxbDateAdapter;
import cn.gtmap.estateplat.utils.JaxbStringNoNullAdapter;

import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;
import java.util.Date;

@XmlRootElement(
        name = "Head"
)
public class HeadModel {
    private String bizMsgID;
    private String ASID;
    private String areaCode;
    private String recType;
    private String rightType;
    private String regType;
    private Date createDate;
    private String recFlowID;
    private String regOrgID;
    private String parcelID;
    private String estateNum;
    private String digitalSign;
    private String preEstateNum;
    private String certCount;
    private String proofCount;
    private String preCertID;
    private String exchangeMode;
    private String logoutRecFlowID;
    public HeadModel() {
    }

    @XmlElement(
            name = "BizMsgID"
    )
    public String getBizMsgID() {
        return this.bizMsgID;
    }

    public void setBizMsgID(String bizMsgID) {
        this.bizMsgID = bizMsgID;
    }

    @XmlElement(
            name = "ASID"
    )
    public String getASID() {
        return this.ASID;
    }

    public void setASID(String ASID) {
        this.ASID = ASID;
    }

    @XmlElement(
            name = "AreaCode"
    )
    public String getAreaCode() {
        return this.areaCode;
    }

    public void setAreaCode(String areaCode) {
        this.areaCode = areaCode;
    }

    @XmlElement(
            name = "RecType"
    )
    public String getRecType() {
        return this.recType;
    }

    public void setRecType(String recType) {
        this.recType = recType;
    }

    @XmlElement(
            name = "RightType"
    )
    public String getRightType() {
        return this.rightType;
    }

    public void setRightType(String rightType) {
        this.rightType = rightType;
    }

    @XmlElement(
            name = "RegType"
    )
    public String getRegType() {
        return this.regType;
    }

    public void setRegType(String regType) {
        this.regType = regType;
    }

    @XmlElement(
            name = "CreateDate"
    )
    @XmlJavaTypeAdapter(JaxbDateAdapter.class)
    public Date getCreateDate() {
        return this.createDate;
    }

    public void setCreateDate(Date createDate) {
        this.createDate = createDate;
    }

    @XmlElement(
            name = "RecFlowID"
    )
    public String getRecFlowID() {
        return this.recFlowID;
    }

    public void setRecFlowID(String recFlowID) {
        this.recFlowID = recFlowID;
    }

    @XmlElement(
            name = "RegOrgID"
    )
    public String getRegOrgID() {
        return this.regOrgID;
    }

    public void setRegOrgID(String regOrgID) {
        this.regOrgID = regOrgID;
    }

    @XmlElement(
            name = "ParcelID"
    )
    public String getParcelID() {
        return this.parcelID;
    }

    public void setParcelID(String parcelID) {
        this.parcelID = parcelID;
    }

    @XmlElement(
            name = "EstateNum"
    )
    public String getEstateNum() {
        return this.estateNum;
    }

    public void setEstateNum(String estateNum) {
        this.estateNum = estateNum;
    }

    @XmlElement(
            name = "DigitalSign"
    )
    public String getDigitalSign() {
        return this.digitalSign;
    }

    public void setDigitalSign(String digitalSign) {
        this.digitalSign = digitalSign;
    }

    @XmlElement(
            name = "PreEstateNum"
    )
    public String getPreEstateNum() {
        return this.preEstateNum;
    }

    public void setPreEstateNum(String preEstateNum) {
        this.preEstateNum = preEstateNum;
    }

    @XmlElement(
            name = "CertCount"
    )
    public String getCertCount() {
        return this.certCount;
    }

    public void setCertCount(String certCount) {
        this.certCount = certCount;
    }

    @XmlElement(
            name = "ProofCount"
    )
    public String getProofCount() {
        return this.proofCount;
    }

    public void setProofCount(String proofCount) {
        this.proofCount = proofCount;
    }

    @XmlElement(
            name = "PreCertID"
    )
    public String getPreCertID() {
        return this.preCertID;
    }

    public void setPreCertID(String preCertID) {
        this.preCertID = preCertID;
    }

    @XmlElement(
            name = "ExchangeMode"
    )
    @XmlJavaTypeAdapter(JaxbStringNoNullAdapter.class)
    public String getExchangeMode() {
        return exchangeMode;
    }

    public void setExchangeMode(String exchangeMode) {
        this.exchangeMode = exchangeMode;
    }
    @XmlElement(
            name = "LogoutRecFlowID"
    )
    @XmlJavaTypeAdapter(JaxbStringNoNullAdapter.class)
    public String getLogoutRecFlowID() {
        return logoutRecFlowID;
    }

    public void setLogoutRecFlowID(String logoutRecFlowID) {
        this.logoutRecFlowID = logoutRecFlowID;
    }
}
